<?php
# dvdisaster: Russian homepage translation
# Copyright (C) 2007-2012 Igor Gorbounov
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!-- Insert actual page content below -->

<h3 class="top">Выходные данные</h3>

Carsten Gnörlich <br>
Beerenkamp 23 <br>
59514 Welver / Germany<br>
Tel.: +49 2384 941174<pre> </pre>
E-Mail: carsten@dvdisaster.org<br>
Internet: www.dvdisaster.org

<pre> </pre>

Ответственный за содержимое сайта: <p>
Carsten Gnörlich (адрес смотри выше).

<pre> </pre>

Эти выходные данные относятся к веб-сайтам:<br>
<a href="http://dvdisaster.com">dvdisaster.com</a>, &nbsp;
<a href="http://dvdisaster.de">dvdisaster.de</a>, &nbsp;
<a href="http://dvdisaster.net">dvdisaster.net</a>, &nbsp;
<a href="http://dvdisaster.org">dvdisaster.org</a>.

<!-- do not change below -->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>
